@@ -17,8 +17,8 @@
 
 #include "k3b_export.h"
 
-#include <QtCore/QIODevice>
-#include <QtCore/QScopedPointer>
+#include <QIODevice>
+#include <QScopedPointer>
 
 
 namespace K3b {
@@ -28,7 +28,7 @@ namespace K3b {
     class LIBK3B_EXPORT AudioZeroDataReader : public QIODevice
     {
     public:
-        AudioZeroDataReader( AudioZeroData& source, QObject* parent = 0 );
+        explicit AudioZeroDataReader( AudioZeroData& source, QObject* parent = 0 );
         ~AudioZeroDataReader();
 
         virtual bool open( OpenMode mode );
