@@ -18,9 +18,9 @@
 
 #include <config-k3b.h>
 
-#include <QtCore/QDebug>
-#include <QtCore/QFile>
-#include <QtCore/QStringList>
+#include <QDebug>
+#include <QFile>
+#include <QStringList>
 
 #include <math.h>
 #include <stdio.h>
