@@ -18,10 +18,10 @@
 
 #include <KAuth/KAuthHelperSupport>
 
-#include <QtCore/QFile>
-#include <QtCore/QProcess>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
+#include <QFile>
+#include <QProcess>
+#include <QString>
+#include <QStringList>
 
 #include <grp.h>
 #include <sys/types.h>
@@ -146,7 +146,7 @@ KAuth::ActionReply Helper::addtogroup( QVariantMap args )
     } else {
         reply = KAuth::ActionReply::HelperErrorReply();
         reply.setErrorCode( (KAuth::ActionReply::Error) errorCode );
-        reply.setErrorDescription( QString( "gpasswd --add " + userName + " " + groupName + " : " + QString::fromLocal8Bit( gpasswd.readAllStandardError().data() ) ) );
+        reply.setErrorDescription( QString( "gpasswd --add " + userName + ' ' + groupName + " : " + QString::fromLocal8Bit( gpasswd.readAllStandardError().data() ) ) );
     }
 
     return reply;
