@@ -15,7 +15,7 @@
 #ifndef _K3B_DEVICE_MENU_H_
 #define _K3B_DEVICE_MENU_H_
 
-#include <QtWidgets/QMenu>
+#include <QMenu>
 
 namespace Device {
     class Device;
@@ -35,7 +35,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        DeviceMenu( QWidget* parent = 0 );
+        explicit DeviceMenu( QWidget* parent = 0 );
         ~DeviceMenu();
 
     private:
