@@ -17,7 +17,7 @@
 
 #include "k3bmedium.h"
 #include <KCompletion/KComboBox>
-#include <QtCore/QList>
+#include <QList>
 
 namespace K3b {
     namespace Device {
@@ -37,7 +37,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        MediaSelectionComboBox( QWidget* parent );
+        explicit MediaSelectionComboBox( QWidget* parent );
         virtual ~MediaSelectionComboBox();
 
         /**
