@@ -15,8 +15,8 @@
 #ifndef _K3B_META_ITEM_MODEL_H_
 #define _K3B_META_ITEM_MODEL_H_
 
-#include <QtCore/QAbstractItemModel>
-#include <QtCore/QUrl>
+#include <QAbstractItemModel>
+#include <QUrl>
 
 class QIcon;
 
@@ -36,7 +36,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        MetaItemModel( QObject* parent = 0 );
+        explicit MetaItemModel( QObject* parent = 0 );
         ~MetaItemModel();
 
         QModelIndex indexForSubModel( QAbstractItemModel* model ) const;
