@@ -14,11 +14,11 @@
  */
 
 
-#ifndef K3B_AUDIO_RIP_THREAD_H
-#define K3B_AUDIO_RIP_THREAD_H
+#ifndef K3B_AUDIO_RIP_JOB_H
+#define K3B_AUDIO_RIP_JOB_H
 
 #include "k3bmassaudioencodingjob.h"
-#include <QtCore/QScopedPointer>
+#include <QScopedPointer>
 
 
 namespace K3b {
